pub trait FusedStream: Stream {
// Required method
fn is_terminated(&self) -> bool;
}Expand description
A stream which tracks whether or not the underlying stream should no longer be polled.
is_terminated will return true if a future should no longer be polled.
Usually, this state occurs after poll_next (or try_poll_next) returned
Poll::Ready(None). However, is_terminated may also return true if a
stream has become inactive and can no longer make progress and should be
ignored or dropped rather than being polled again.
Required Methods
Sourcefn is_terminated(&self) -> bool
fn is_terminated(&self) -> bool
Returns true if the stream should no longer be polled.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.